@@ -15,14 +15,15 @@ class Mol:
         mol = Mol()
         mol.id = ser['id']
         mol.mol_code = ser['mol_code']
-        mol.names = eval(ser['names'])
+        # mol.names = eval(ser['names'])
         mol.inchi = ser['inchi']
         mol.smiles = ser['smiles']
+        return mol
 
     def __init__(self):
         self.id: int = 0
         self.mol_code: str = ''
-        self.names: [str] = []
+        # self.names: [str] = []
         self.inchi: str = ''
         self.smiles: str = ''
 
